"""
backend_statistic_chart automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_statistic_chart_data import BackendStatisticChartData
class BackendStatisticChart(BaseModel):
    labels: Optional[List[str]] = Field(default=None, alias="labels")
    data: Optional[List[BackendStatisticChartData]] = Field(default=None, alias="data")
    series: Optional[List[str]] = Field(default=None, alias="series")
    pass



"""
system_o_auth_configuration automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class SystemOAuthConfiguration(BaseModel):
    issuer: Optional[str] = Field(default=None, alias="issuer")
    token_endpoint: Optional[str] = Field(default=None, alias="token_endpoint")
    token_endpoint_auth_methods_supported: Optional[List[str]] = Field(default=None, alias="token_endpoint_auth_methods_supported")
    userinfo_endpoint: Optional[str] = Field(default=None, alias="userinfo_endpoint")
    scopes_supported: Optional[List[str]] = Field(default=None, alias="scopes_supported")
    claims_supported: Optional[List[str]] = Field(default=None, alias="claims_supported")
    pass



"""
BackendAuditTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .backend_audit import BackendAudit
from .backend_audit_collection import BackendAuditCollection
from .common_message_exception import CommonMessageException

class BackendAuditTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def get(self, audit_id: str) -> BackendAudit:
        try:
            path_params = {}
            path_params["audit_id"] = audit_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/audit/$audit_id<[0-9]+>", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendAudit.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 410:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_all(self, start_index: int, count: int, search: str, from_: str, to: str, app_id: int, user_id: int, event: str, ip: str, message: str) -> BackendAuditCollection:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["event"] = event
            query_params["ip"] = ip
            query_params["message"] = message

            query_struct_names = []

            url = self.parser.url("/backend/audit", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendAuditCollection.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))





"""
backend_webhook automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_webhook_response import BackendWebhookResponse
class BackendWebhook(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    event_id: Optional[int] = Field(default=None, alias="eventId")
    user_id: Optional[int] = Field(default=None, alias="userId")
    name: Optional[str] = Field(default=None, alias="name")
    endpoint: Optional[str] = Field(default=None, alias="endpoint")
    responses: Optional[List[BackendWebhookResponse]] = Field(default=None, alias="responses")
    pass



"""
backend_cronjob automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .common_metadata import CommonMetadata
from .backend_cronjob_error import BackendCronjobError
class BackendCronjob(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    cron: Optional[str] = Field(default=None, alias="cron")
    action: Optional[str] = Field(default=None, alias="action")
    execute_date: Optional[datetime.datetime] = Field(default=None, alias="executeDate")
    exit_code: Optional[int] = Field(default=None, alias="exitCode")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    errors: Optional[List[BackendCronjobError]] = Field(default=None, alias="errors")
    pass



"""
system_route automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .system_route_path import SystemRoutePath
class SystemRoute(BaseModel):
    routes: Optional[SystemRoutePath] = Field(default=None, alias="routes")
    pass



"""
consumer_transaction_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .common_collection import CommonCollection
from .consumer_transaction import ConsumerTransaction
class ConsumerTransactionCollection(CommonCollection[ConsumerTransaction]):
    pass



"""
backend_database_tables automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class BackendDatabaseTables(BaseModel):
    tables: Optional[List[str]] = Field(default=None, alias="tables")
    pass



"""
backend_dashboard automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_statistic_chart import BackendStatisticChart
from .backend_dashboard_apps import BackendDashboardApps
from .backend_dashboard_requests import BackendDashboardRequests
from .backend_dashboard_users import BackendDashboardUsers
class BackendDashboard(BaseModel):
    errors_per_operation: Optional[BackendStatisticChart] = Field(default=None, alias="errorsPerOperation")
    incoming_requests: Optional[BackendStatisticChart] = Field(default=None, alias="incomingRequests")
    incoming_transactions: Optional[BackendStatisticChart] = Field(default=None, alias="incomingTransactions")
    most_used_operations: Optional[BackendStatisticChart] = Field(default=None, alias="mostUsedOperations")
    time_per_operation: Optional[BackendStatisticChart] = Field(default=None, alias="timePerOperation")
    test_coverage: Optional[BackendStatisticChart] = Field(default=None, alias="testCoverage")
    latest_apps: Optional[BackendDashboardApps] = Field(default=None, alias="latestApps")
    latest_requests: Optional[BackendDashboardRequests] = Field(default=None, alias="latestRequests")
    latest_users: Optional[BackendDashboardUsers] = Field(default=None, alias="latestUsers")
    pass



"""
CommonMessageException automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import sdkgen

from .common_message import CommonMessage

class CommonMessageException(sdkgen.KnownStatusCodeException):
    payload: CommonMessage = None

    def __init__(self, payload):
        self.payload = CommonMessage.model_validate_json(json_data=payload)

    def get_payload(self) -> CommonMessage:
        return self.payload



"""
consumer_log automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
class ConsumerLog(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    app_id: Optional[int] = Field(default=None, alias="appId")
    ip: Optional[str] = Field(default=None, alias="ip")
    user_agent: Optional[str] = Field(default=None, alias="userAgent")
    method: Optional[str] = Field(default=None, alias="method")
    path: Optional[str] = Field(default=None, alias="path")
    header: Optional[str] = Field(default=None, alias="header")
    body: Optional[str] = Field(default=None, alias="body")
    date: Optional[datetime.datetime] = Field(default=None, alias="date")
    pass



"""
backend_connection_introspection_entities automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class BackendConnectionIntrospectionEntities(BaseModel):
    entities: Optional[List[str]] = Field(default=None, alias="entities")
    pass



"""
backend_scope_update automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_scope import BackendScope
class BackendScopeUpdate(BackendScope):
    pass



"""
ConsumerGrantTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .common_message import CommonMessage
from .common_message_exception import CommonMessageException
from .consumer_grant_collection import ConsumerGrantCollection

class ConsumerGrantTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def delete(self, grant_id: str) -> CommonMessage:
        try:
            path_params = {}
            path_params["grant_id"] = grant_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/consumer/grant/$grant_id<[0-9]+>", path_params)

            headers = {}

            response = self.http_client.delete(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 410:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_all(self, start_index: int, count: int, search: str) -> ConsumerGrantCollection:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search

            query_struct_names = []

            url = self.parser.url("/consumer/grant", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return ConsumerGrantCollection.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))





"""
system_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .system_schema_type_schema import SystemSchemaTypeSchema
from .system_schema_form import SystemSchemaForm
class SystemSchema(BaseModel):
    schema_: Optional[SystemSchemaTypeSchema] = Field(default=None, alias="schema")
    form: Optional[SystemSchemaForm] = Field(default=None, alias="form")
    pass



"""
backend_event automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .common_metadata import CommonMetadata
class BackendEvent(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    name: Optional[str] = Field(default=None, alias="name")
    description: Optional[str] = Field(default=None, alias="description")
    schema_: Optional[str] = Field(default=None, alias="schema")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    pass



"""
system_health_check automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class SystemHealthCheck(BaseModel):
    healthy: Optional[bool] = Field(default=None, alias="healthy")
    error: Optional[str] = Field(default=None, alias="error")
    pass



"""
backend_connection_index automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .backend_connection_index_entry import BackendConnectionIndexEntry
class BackendConnectionIndex(BaseModel):
    connections: Optional[List[BackendConnectionIndexEntry]] = Field(default=None, alias="connections")
    pass



"""
BackendAppTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .backend_app import BackendApp
from .backend_app_collection import BackendAppCollection
from .backend_app_create import BackendAppCreate
from .backend_app_update import BackendAppUpdate
from .common_message import CommonMessage
from .common_message_exception import CommonMessageException

class BackendAppTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def delete_token(self, app_id: str, token_id: str) -> CommonMessage:
        try:
            path_params = {}
            path_params["app_id"] = app_id
            path_params["token_id"] = token_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/app/$app_id<[0-9]+>/token/:token_id", path_params)

            headers = {}

            response = self.http_client.delete(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 410:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def delete(self, app_id: str) -> CommonMessage:
        try:
            path_params = {}
            path_params["app_id"] = app_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/app/$app_id<[0-9]+|^~>", path_params)

            headers = {}

            response = self.http_client.delete(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 410:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def update(self, app_id: str, payload: BackendAppUpdate) -> CommonMessage:
        try:
            path_params = {}
            path_params["app_id"] = app_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/app/$app_id<[0-9]+|^~>", path_params)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.put(url, headers=headers, params=self.parser.query(query_params, query_struct_names), json=payload.model_dump(by_alias=True))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 410:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get(self, app_id: str) -> BackendApp:
        try:
            path_params = {}
            path_params["app_id"] = app_id

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/app/$app_id<[0-9]+|^~>", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendApp.model_validate_json(json_data=response.content)

            if response.status_code == 404:
                raise CommonMessageException(response.content)
            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 410:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def create(self, payload: BackendAppCreate) -> CommonMessage:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/app", path_params)

            headers = {}
            headers["Content-Type"] = "application/json"

            response = self.http_client.post(url, headers=headers, params=self.parser.query(query_params, query_struct_names), json=payload.model_dump(by_alias=True))

            if response.status_code >= 200 and response.status_code < 300:
                return CommonMessage.model_validate_json(json_data=response.content)

            if response.status_code == 400:
                raise CommonMessageException(response.content)
            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_all(self, start_index: int, count: int, search: str) -> BackendAppCollection:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search

            query_struct_names = []

            url = self.parser.url("/backend/app", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendAppCollection.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))





"""
common_form_container automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
from .common_form_element_input import CommonFormElementInput
from .common_form_element_select import CommonFormElementSelect
from .common_form_element_tag import CommonFormElementTag
from .common_form_element_text_area import CommonFormElementTextArea
class CommonFormContainer(BaseModel):
    element: Optional[List[Union[CommonFormElementInput, CommonFormElementSelect, CommonFormElementTag, CommonFormElementTextArea]]] = Field(default=None, alias="element")
    pass



"""
backend_app automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
import datetime
from .common_metadata import CommonMetadata
from .backend_token import BackendToken
class BackendApp(BaseModel):
    id: Optional[int] = Field(default=None, alias="id")
    user_id: Optional[int] = Field(default=None, alias="userId")
    status: Optional[int] = Field(default=None, alias="status")
    name: Optional[str] = Field(default=None, alias="name")
    url: Optional[str] = Field(default=None, alias="url")
    parameters: Optional[str] = Field(default=None, alias="parameters")
    app_key: Optional[str] = Field(default=None, alias="appKey")
    app_secret: Optional[str] = Field(default=None, alias="appSecret")
    metadata: Optional[CommonMetadata] = Field(default=None, alias="metadata")
    date: Optional[datetime.datetime] = Field(default=None, alias="date")
    scopes: Optional[List[str]] = Field(default=None, alias="scopes")
    tokens: Optional[List[BackendToken]] = Field(default=None, alias="tokens")
    pass



"""
consumer_authorize_request automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class ConsumerAuthorizeRequest(BaseModel):
    response_type: Optional[str] = Field(default=None, alias="responseType")
    client_id: Optional[str] = Field(default=None, alias="clientId")
    redirect_uri: Optional[str] = Field(default=None, alias="redirectUri")
    scope: Optional[str] = Field(default=None, alias="scope")
    state: Optional[str] = Field(default=None, alias="state")
    allow: Optional[bool] = Field(default=None, alias="allow")
    pass



"""
BackendStatisticTag automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import requests
import sdkgen
from requests import RequestException
from typing import List

from .backend_statistic_chart import BackendStatisticChart
from .backend_statistic_count import BackendStatisticCount
from .common_message_exception import CommonMessageException

class BackendStatisticTag(sdkgen.TagAbstract):
    def __init__(self, http_client: requests.Session, parser: sdkgen.Parser):
        super().__init__(http_client, parser)


    def get_used_points(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["operationId"] = operation_id
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["ip"] = ip
            query_params["userAgent"] = user_agent
            query_params["method"] = method
            query_params["path"] = path
            query_params["header"] = header
            query_params["body"] = body

            query_struct_names = []

            url = self.parser.url("/backend/statistic/used_points", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_time_per_operation(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["operationId"] = operation_id
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["ip"] = ip
            query_params["userAgent"] = user_agent
            query_params["method"] = method
            query_params["path"] = path
            query_params["header"] = header
            query_params["body"] = body

            query_struct_names = []

            url = self.parser.url("/backend/statistic/time_per_operation", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_time_average(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["operationId"] = operation_id
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["ip"] = ip
            query_params["userAgent"] = user_agent
            query_params["method"] = method
            query_params["path"] = path
            query_params["header"] = header
            query_params["body"] = body

            query_struct_names = []

            url = self.parser.url("/backend/statistic/time_average", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_test_coverage(self) -> BackendStatisticChart:
        try:
            path_params = {}

            query_params = {}

            query_struct_names = []

            url = self.parser.url("/backend/statistic/test_coverage", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_most_used_operations(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["operationId"] = operation_id
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["ip"] = ip
            query_params["userAgent"] = user_agent
            query_params["method"] = method
            query_params["path"] = path
            query_params["header"] = header
            query_params["body"] = body

            query_struct_names = []

            url = self.parser.url("/backend/statistic/most_used_operations", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_most_used_apps(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["operationId"] = operation_id
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["ip"] = ip
            query_params["userAgent"] = user_agent
            query_params["method"] = method
            query_params["path"] = path
            query_params["header"] = header
            query_params["body"] = body

            query_struct_names = []

            url = self.parser.url("/backend/statistic/most_used_apps", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_issued_tokens(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["operationId"] = operation_id
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["ip"] = ip
            query_params["userAgent"] = user_agent
            query_params["method"] = method
            query_params["path"] = path
            query_params["header"] = header
            query_params["body"] = body

            query_struct_names = []

            url = self.parser.url("/backend/statistic/issued_tokens", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_incoming_transactions(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["operationId"] = operation_id
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["ip"] = ip
            query_params["userAgent"] = user_agent
            query_params["method"] = method
            query_params["path"] = path
            query_params["header"] = header
            query_params["body"] = body

            query_struct_names = []

            url = self.parser.url("/backend/statistic/incoming_transactions", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_incoming_requests(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["operationId"] = operation_id
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["ip"] = ip
            query_params["userAgent"] = user_agent
            query_params["method"] = method
            query_params["path"] = path
            query_params["header"] = header
            query_params["body"] = body

            query_struct_names = []

            url = self.parser.url("/backend/statistic/incoming_requests", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_errors_per_operation(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticChart:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["operationId"] = operation_id
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["ip"] = ip
            query_params["userAgent"] = user_agent
            query_params["method"] = method
            query_params["path"] = path
            query_params["header"] = header
            query_params["body"] = body

            query_struct_names = []

            url = self.parser.url("/backend/statistic/errors_per_operation", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticChart.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))

    def get_count_requests(self, start_index: int, count: int, search: str, from_: str, to: str, operation_id: int, app_id: int, user_id: int, ip: str, user_agent: str, method: str, path: str, header: str, body: str) -> BackendStatisticCount:
        try:
            path_params = {}

            query_params = {}
            query_params["startIndex"] = start_index
            query_params["count"] = count
            query_params["search"] = search
            query_params["from"] = from_
            query_params["to"] = to
            query_params["operationId"] = operation_id
            query_params["appId"] = app_id
            query_params["userId"] = user_id
            query_params["ip"] = ip
            query_params["userAgent"] = user_agent
            query_params["method"] = method
            query_params["path"] = path
            query_params["header"] = header
            query_params["body"] = body

            query_struct_names = []

            url = self.parser.url("/backend/statistic/count_requests", path_params)

            headers = {}

            response = self.http_client.get(url, headers=headers, params=self.parser.query(query_params, query_struct_names))

            if response.status_code >= 200 and response.status_code < 300:
                return BackendStatisticCount.model_validate_json(json_data=response.content)

            if response.status_code == 401:
                raise CommonMessageException(response.content)
            if response.status_code == 500:
                raise CommonMessageException(response.content)

            raise sdkgen.UnknownStatusCodeException("The server returned an unknown status code")
        except RequestException as e:
            raise sdkgen.ClientException("An unknown error occurred: " + str(e))





"""
backend_operation_schema automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
class BackendOperationSchema(BaseModel):
    description: Optional[str] = Field(default=None, alias="description")
    type: Optional[str] = Field(default=None, alias="type")
    format: Optional[str] = Field(default=None, alias="format")
    enum: Optional[str] = Field(default=None, alias="enum")
    pass



"""
marketplace_collection automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

from pydantic import BaseModel, Field, GetCoreSchemaHandler
from pydantic_core import CoreSchema, core_schema
from typing import Any, Dict, Generic, List, Optional, TypeVar, Union
T = TypeVar("T")
class MarketplaceCollection(BaseModel, Generic[T]):
    total_results: Optional[int] = Field(default=None, alias="totalResults")
    start_index: Optional[int] = Field(default=None, alias="startIndex")
    items_per_page: Optional[int] = Field(default=None, alias="itemsPerPage")
    entry: Optional[List[T]] = Field(default=None, alias="entry")
    pass



"""
MarketplaceMessageException automatically generated by SDKgen please do not edit this file manually
https://sdkgen.app
"""

import sdkgen

from .marketplace_message import MarketplaceMessage

class MarketplaceMessageException(sdkgen.KnownStatusCodeException):
    payload: MarketplaceMessage = None

    def __init__(self, payload):
        self.payload = MarketplaceMessage.model_validate_json(json_data=payload)

    def get_payload(self) -> MarketplaceMessage:
        return self.payload
